@@ -20,7 +20,7 @@
 
 #include <qstring.h>
 
-#include <kglobal.h>
+
 #include <ksharedconfig.h>
 #include <kconfiggroup.h>
 
@@ -30,110 +30,105 @@ TextEffectConfig::TextEffectConfig()
 
 void TextEffectConfig::load()
 {
-	KConfigGroup config(KGlobal::config(), "TextEffect Plugin");
+    KConfigGroup config(KSharedConfig::openConfig(), "TextEffect Plugin");
 
-	mColors = config.readEntry("Colors", QStringList() );
-	if(mColors.isEmpty())
-	{
-            mColors= defaultColorList();
-	}
-	mColorRandom = config.readEntry("Color Random Order", false);
-	mColorLines = config.readEntry("Color change every lines", true);
-	mColorWords = config.readEntry("Color change every words", false);
-	mColorChar = config.readEntry("Color change every char", false);
+    mColors = config.readEntry("Colors", defaultColorList());
+    mColorRandom = config.readEntry("Color Random Order", false);
+    mColorLines = config.readEntry("Color change every lines", true);
+    mColorWords = config.readEntry("Color change every words", false);
+    mColorChar = config.readEntry("Color change every char", false);
 
-	mLamer = config.readEntry("L4m3r", false);
-	mWaves = config.readEntry("WaVeS", false);
+    mLamer = config.readEntry("L4m3r", false);
+    mWaves = config.readEntry("WaVeS", false);
 }
 
 QStringList TextEffectConfig::defaultColorList()
 {
-    
-    return QString(QLatin1String("#00BBDD,#0088DD,#0000DD,#8800DD,#DD00DD,#DD0088,#DD0000,#DD8800,#DDBB00,#88BB00,#00BB00" )).split(',');
+    return QStringLiteral("#00BBDD,#0088DD,#0000DD,#8800DD,#DD00DD,#DD0088,#DD0000,#DD8800,#DDBB00,#88BB00,#00BB00").split(',');
 }
 
 void TextEffectConfig::save()
 {
-	KConfigGroup config(KGlobal::config(), "TextEffect Plugin");
+    KConfigGroup config(KSharedConfig::openConfig(), "TextEffect Plugin");
 
-	config.writeEntry("Colors", mColors );
-	config.writeEntry("Color Random Order", mColorRandom);
-	config.writeEntry("Color change every lines", mColorLines);
-	config.writeEntry("Color change every words", mColorWords);
-	config.writeEntry("Color change every char", mColorChar);
+    config.writeEntry("Colors", mColors);
+    config.writeEntry("Color Random Order", mColorRandom);
+    config.writeEntry("Color change every lines", mColorLines);
+    config.writeEntry("Color change every words", mColorWords);
+    config.writeEntry("Color change every char", mColorChar);
 
-	config.writeEntry("L4m3r", mLamer);
-	config.writeEntry("WaVeS", mWaves);
+    config.writeEntry("L4m3r", mLamer);
+    config.writeEntry("WaVeS", mWaves);
 
-	config.sync();
+    config.sync();
 }
 
 QStringList TextEffectConfig::colors() const
 {
-	return mColors;
+    return mColors;
 }
 
 bool TextEffectConfig::colorRandom() const
 {
-	return mColorRandom;
+    return mColorRandom;
 }
 
 bool TextEffectConfig::colorWords() const
 {
-	return mColorWords;
+    return mColorWords;
 }
 
 bool TextEffectConfig::colorLines() const
 {
-	return mColorLines;
+    return mColorLines;
 }
 
 bool TextEffectConfig::colorChar() const
 {
-	return mColorChar;
+    return mColorChar;
 }
 
 bool TextEffectConfig::lamer() const
 {
-	return mLamer;
+    return mLamer;
 }
 
 bool TextEffectConfig::waves() const
 {
-	return mWaves;
+    return mWaves;
 }
 
 void TextEffectConfig::setColors(const QStringList &newColors)
 {
-	mColors = newColors;
+    mColors = newColors;
 }
 
 void TextEffectConfig::setColorWords(bool newWords)
 {
-	mColorWords = newWords;
+    mColorWords = newWords;
 }
 
 void TextEffectConfig::setColorLines(bool newLines)
 {
-	mColorLines = newLines;
+    mColorLines = newLines;
 }
 
 void TextEffectConfig::setColorRandom(bool newRandom)
 {
-	mColorRandom = newRandom;
+    mColorRandom = newRandom;
 }
 
 void TextEffectConfig::setColorChar(bool newChar)
 {
-	mColorChar = newChar;
+    mColorChar = newChar;
 }
 
 void TextEffectConfig::setLamer(bool newLamers)
 {
-	mLamer = newLamers;
+    mLamer = newLamers;
 }
 
 void TextEffectConfig::setWaves(bool newWaves)
 {
-	mWaves = newWaves;
+    mWaves = newWaves;
 }
