@@ -36,6 +36,7 @@ namespace XMPP
 {
 	class TLSHandler;
 	class Connector;
+	class StreamFeatures;
 
 	class ClientStream : public Stream
 	{
@@ -51,7 +52,8 @@ namespace XMPP
 		};
 		enum Warning {
 			WarnOldVersion,             // server uses older XMPP/Jabber "0.9" protocol
-			WarnNoTLS                   // there is no chance for TLS at this point
+			WarnNoTLS,                  // there is no chance for TLS at this point
+			WarnSMReconnection          // SM started a quiet stream reconnection
 		};
 		enum NegCond {
 			HostGone,                   // host no longer hosted
@@ -91,18 +93,6 @@ namespace XMPP
 			AllowPlainOverTLS
 		};
 
-		struct SMState {
-			QList<QPair<unsigned long, bool> > sm_receive_queue;
-			QList<QPair<QDomElement, bool> > sm_send_queue;
-			unsigned long sm_receive_count;
-			unsigned long sm_server_last_handled;
-			int sm_stanzas_notify;
-
-			bool sm_resumtion_supported;
-			QString sm_resumption_id;
-			QPair<QString,int> sm_resumption_location;
-		};
-
 		ClientStream(Connector *conn, TLSHandler *tlsHandler=0, QObject *parent=0);
 		ClientStream(const QString &host, const QString &defRealm, ByteStream *bs, QCA::TLS *tls=0, QObject *parent=0); // server
 		~ClientStream();
@@ -119,6 +109,9 @@ namespace XMPP
 		void setRealm(const QString &s);
 		void setAuthzid(const QString &s);
 		void continueAfterParams();
+		void setSaslMechanismProvider(const QString &m, const QString &p);
+		QString saslMechanismProvider(const QString &m) const;
+		QCA::Provider::Context *currentSASLContext() const;
 
 		void setSCRAMStoredSaltedHash(const QString &s);
 		const QString getSCRAMStoredSaltedHash();
@@ -152,7 +145,7 @@ namespace XMPP
 		void close();
 		bool stanzaAvailable() const;
 		Stanza read();
-		void write(const Stanza &s, bool notify = false);
+		void write(const Stanza &s);
 
 		int errorCondition() const;
 		QString errorText() const;
@@ -162,22 +155,23 @@ namespace XMPP
 		void writeDirect(const QString &s);
 		void setNoopTime(int mills);
 
-		// session management stuff
-		bool isStreamManagementActive();
-		void ackLastMessageStanza();
-
-		SMState getSMState() const;
-		void setSMState(SMState state);
+		// Stream management
+		bool isResumed() const;
+		void setSMEnabled(bool enable);
 
 		// barracuda extension
 		QStringList hosts() const;
 
+		const StreamFeatures &streamFeatures() const;	
+		QList<QDomElement> unhandledFeatures() const;
+
 	signals:
 		void connected();
 		void securityLayerActivated(int);
 		void needAuthParams(bool user, bool pass, bool realm);
 		void authenticated();
 		void warning(int);
+		void haveUnhandledFeatures();
 		void incomingXml(const QString &s);
 		void outgoingXml(const QString &s);
 		void stanzasAcked(int);
